package com.datacloudsec.scan.service.impl;

import com.datacloudsec.annotations.Transactional;
import com.datacloudsec.exception.UEException;
import com.datacloudsec.scan.common.Constant;
import com.datacloudsec.scan.dao.AlarmlogMapper;
import com.datacloudsec.scan.dao.DBBugMapper;
import com.datacloudsec.scan.dao.DbMapper;
import com.datacloudsec.scan.dao.DeviceGroupMapper;
import com.datacloudsec.scan.dao.DeviceMapper;
import com.datacloudsec.scan.dao.LogMapper;
import com.datacloudsec.scan.entity.LicCmp;
import com.datacloudsec.scan.entity.Task;
import com.datacloudsec.scan.entity.User;
import com.datacloudsec.scan.service.IDb;
import com.datacloudsec.scan.service.IEngine;
import com.datacloudsec.scan.service.IReport;
import com.datacloudsec.scan.tasks.InitSystemTask;
import com.datacloudsec.scan.tasks.scheduler.job.AlermJob;
import com.datacloudsec.scan.tasks.scheduler.job.SysLogJob;
import com.datacloudsec.utils.ComonZipUtil;
import com.datacloudsec.utils.DataRule;
import com.datacloudsec.utils.FtpUtil;
import com.datacloudsec.utils.IPUtil;
import com.datacloudsec.utils.InstanceUtil;
import com.datacloudsec.utils.JsonUtil;
import com.datacloudsec.utils.MybatisUtil;
import com.datacloudsec.utils.ObjectUtil;
import com.datacloudsec.utils.SerializeUtil;
import com.fasterxml.jackson.core.type.TypeReference;
import java.io.File;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import javax.servlet.http.HttpSession;
import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.collections4.MapUtils;
import org.apache.commons.io.FileUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.ibatis.session.SqlSession;
import org.apache.log4j.Logger;

/* loaded from: com_datacloudsec_scan_service_impl.jar:com/datacloudsec/scan/service/impl/DbService.class */
public class DbService extends TaskBaseService implements IDb {
    private Logger LOG = Logger.getLogger(DbService.class);
    private DbMapper dbMapper = (DbMapper) InstanceUtil.newDaoInstance(DbMapper.class);
    private DBBugMapper dbBugMapper = (DBBugMapper) InstanceUtil.newDaoInstance(DBBugMapper.class);
    private DeviceMapper deviceMapper = (DeviceMapper) InstanceUtil.newDaoInstance(DeviceMapper.class);
    private DeviceGroupMapper deviceGroupMapper = (DeviceGroupMapper) InstanceUtil.newDaoInstance(DeviceGroupMapper.class);
    private IEngine engine = (IEngine) InstanceUtil.newServiceInstance(EngineService.class);
    private LogMapper logMapper = (LogMapper) InstanceUtil.newDaoInstance(LogMapper.class);
    private AlarmlogMapper alarmlogMapper = (AlarmlogMapper) InstanceUtil.newDaoInstance(AlarmlogMapper.class);

    public void delete(HttpSession session, Integer id, Integer version) throws Exception {
        delTask(session, id, version);
    }

    public Integer insert(HttpSession session, String name, String desct, Integer type, String alarmMethod, Integer alarmType, String alarmTime, String mailAddr, String smsAddr, String devList, String periodTime, String emailcheck, String smscheck, String confContent, String warningType, Integer val1, String ftpReportType) throws Exception {
        Map<String, String> params = InitSystemTask.licenseApp.getLicenseLic().getParams();
        String cmp = ObjectUtil.getString(params.get("cmp"), "");
        if (!cmp.contains("dbscan")) {
            throw new UEException("数据库扫描任务未授权");
        }
        LicCmp licCmp = getLicCp(cmp, "dbscan");
        if (InitSystemTask.licenseApp.valudate(licCmp.getAuthDay()) != 0) {
            throw new UEException("数据库任务授权已过期");
        }
        User user = null;
        try {
            user = (User) session.getAttribute("userInfo");
            Integer count = this.dbMapper.getTaskCountByName(name, 4, user.getId(), (Integer) null);
            if (count != null && count.intValue() > 0) {
                throw new UEException("任务名称已存在！");
            }
        } catch (Exception e) {
            Integer count2 = this.dbMapper.getTcountForOthers(name, 4, (Integer) null);
            if (count2 != null && count2.intValue() > 0) {
                throw new UEException("任务名称已存在！");
            }
        }
        Integer taskid = add(null, name, desct, type, alarmMethod, alarmType, alarmTime, mailAddr, smsAddr, devList, periodTime, emailcheck, smscheck, null, 4, confContent, warningType, val1, ftpReportType, session);
        if (type.intValue() == 1) {
            boolean bl = true;
            List<Map<String, Object>> taskWebList = this.dbMapper.getTaskDevByTid(taskid);
            for (Map<String, Object> map : taskWebList) {
                Integer devid = ObjectUtil.getInt(map.get("id"));
                try {
                    start(devid);
                } catch (Exception e2) {
                    bl = false;
                    this.LOG.error("立即扫描异常", e2);
                }
            }
            if (bl) {
                this.logMapper.insert(user == null ? "未登录" : user.getName(), "开始扫描数据库任务", "", 1, "扫描成功");
            } else {
                this.logMapper.insert(user == null ? "未登录" : user.getName(), "开始扫描数据库任务", "", 2, "扫描失败");
            }
        }
        startTimer(taskid, type, periodTime, alarmType, alarmMethod, alarmTime);
        return taskid;
    }

    private Integer add(Integer id, String name, String desct, Integer type, String alarmMethod, Integer alarmType, String alarmTime, String mailAddr, String smsAddr, String devList, String periodTime, String emailcheck, String smscheck, Integer version, Integer taskType, String confContent, String warningType, Integer val1, String ftpReportType, HttpSession session) throws Exception {
        String ip;
        Map<String, String> params = InitSystemTask.licenseApp.getLicenseLic().getParams();
        String cmp = ObjectUtil.getString(params.get("cmp"), "");
        LicCmp licCmp = getLicCp(cmp, "dbscan");
        int maxdevice = licCmp.getMaxdevice();
        User user = (User) session.getAttribute("userInfo");
        String rule = DataRule.getRuleWhere(session, "t_task");
        Task task = new Task();
        task.setName(name);
        if (id != null) {
            task.setId(id);
        }
        task.setDesct(desct);
        task.setType(type);
        task.setAlarmMethod(alarmMethod);
        task.setAlarmType(alarmType);
        task.setAlarmTime(alarmTime);
        task.setMailAddr(emailcheck);
        task.setSmsAddr(smscheck);
        task.setPeriodTime(periodTime);
        if (user != null) {
            task.setUid(user.getId());
        }
        task.setTaskType(taskType);
        task.setVersion(version);
        task.setRule(rule);
        task.setConfContent(confContent);
        task.setWarningType(warningType);
        task.setVal1(val1);
        task.setVal2(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date()));
        task.setFtpReportType(ftpReportType);
        if (id != null) {
            task.setId(id);
        }
        if (id == null) {
            List<Map<String, Object>> devListMap = (List) JsonUtil.MAPPER_ESCAPE_HTML.readValue(devList, ArrayList.class);
            int devIpCount = 0;
            for (Map<String, Object> devMap : devListMap) {
                if (devMap != null) {
                    if (devMap.size() == 1) {
                        ip = ObjectUtil.getString(devMap.get("name"), "");
                    } else {
                        Map<String, Object> map = this.deviceMapper.getDevById(ObjectUtil.getInt(ObjectUtil.getString(devMap.get("id"), "").split("\\|")[0]));
                        if (map == null) {
                            continue;
                        } else {
                            ip = ObjectUtil.getString(map.get("ip"), "");
                        }
                    }
                    if (user != null && StringUtils.isNotBlank(user.getIps()) && !IPUtil.ipVaild(ip, user.getIps())) {
                        throw new UEException("IP【" + ip + "】不在扫描范围内，可联系管理员授权扫描此IP");
                    }
                    devIpCount++;
                }
            }
            if (maxdevice > 0 && this.dbMapper.getCountByType(ReportService.REPORT_STATE_FAILED) + devIpCount > maxdevice) {
                throw new UEException("当前资产数已达授权上限[" + maxdevice + "]");
            }
            this.dbMapper.insert(task);
            for (Map<String, Object> devMap2 : devListMap) {
                String[] idarr = ObjectUtil.getString(devMap2.get("id"), "").split("\\|");
                Map<String, Object> map2 = this.deviceMapper.getDevById(ObjectUtil.getInt(idarr[0]));
                if (map2 != null) {
                    Map<String, Object> devGroup = this.deviceGroupMapper.getDevGroupById(ObjectUtil.getInt(map2.get("dgid")));
                    map2.put("devgroup", ObjectUtil.getString(devGroup.get("name"), ""));
                    map2.put("taskId", task.getId());
                    Map<String, Object> confContentMap = (Map) JsonUtil.MAPPER.readValue(ObjectUtil.getString(map2.get("confContent"), ""), HashMap.class);
                    List<Map<String, Object>> confListMap = (List) confContentMap.get(ReportService.REPORT_STATE_FAILED);
                    String confStr = "";
                    Iterator<Map<String, Object>> it = confListMap.iterator();
                    while (true) {
                        if (!it.hasNext()) {
                            break;
                        }
                        Map<String, Object> conf = it.next();
                        if (idarr[2].equals(ObjectUtil.getString(conf.get("db"), ""))) {
                            confStr = JsonUtil.MAPPER.writeValueAsString(conf);
                            break;
                        }
                    }
                    map2.put("confContent", confStr);
                    map2.put("type", 2);
                    map2.put("name", ObjectUtil.getString(devMap2.get("name"), ""));
                    this.dbMapper.insertTaskDevice(map2);
                } else {
                    Map<String, Object> newdev = new HashMap<>();
                    newdev.put("type", 2);
                    newdev.put("taskId", task.getId());
                    newdev.put("name", ObjectUtil.getString(devMap2.get("name"), ""));
                    newdev.put("ip", ObjectUtil.getString(devMap2.get("name"), ""));
                    newdev.put("regionSid", Integer.valueOf((user == null || user.getRegionSid() == null) ? 110000 : user.getRegionSid().intValue()));
                    newdev.put("regionCid", Integer.valueOf((user == null || user.getRegionCid() == null) ? 110101 : user.getRegionCid().intValue()));
                    newdev.put("confContent", JsonUtil.MAPPER.writeValueAsString(devMap2.get("confContent")));
                    this.dbMapper.insertTaskDevice(newdev);
                }
            }
        } else {
            Integer rcount = this.dbMapper.update(task);
            if (rcount != null && rcount.intValue() == 0) {
                throw new UEException("数据已被修改或删除，请刷新页面或返回");
            }
        }
        if (user != null) {
            if (StringUtils.isNotBlank(mailAddr)) {
                this.dbMapper.delEmail(user.getId());
                String[] mail = mailAddr.split(",");
                for (String ml : mail) {
                    this.dbMapper.insertEmail(ml, user.getId());
                }
            }
            if (StringUtils.isNotBlank(smsAddr)) {
                this.dbMapper.delPhone(user.getId());
                String[] sms = smsAddr.split(",");
                for (String s : sms) {
                    this.dbMapper.insertPhone(s, user.getId());
                }
            }
        }
        return task.getId();
    }

    public void insertTaskDev(Map<String, Object> map) throws Exception {
        this.dbMapper.insertTaskDevice(map);
    }

    public void update(HttpSession session, Integer id, String name, String desct, Integer type, String alarmMethod, Integer alarmType, String alarmTime, String mailAddr, String smsAddr, String periodTime, String emailcheck, String smscheck, Integer version, String confContent, String warningType, Integer val1, String ftpReportType) throws Exception {
        Integer uid = ((User) session.getAttribute("userInfo")).getId();
        Integer count = this.dbMapper.getTaskCountByName(name, 4, uid, id);
        if (count != null && count.intValue() > 0) {
            throw new UEException("任务名称已存在！");
        }
        add(id, name, desct, type, alarmMethod, alarmType, alarmTime, mailAddr, smsAddr, null, periodTime, emailcheck, smscheck, version, 4, confContent, warningType, val1, ftpReportType, session);
        stopTimer(session, id);
        if (alarmType.intValue() == 2 || type.intValue() == 2) {
            startTimer(id, type, periodTime, alarmType, alarmMethod, alarmTime);
        }
    }

    public void start(Integer devid) throws Exception {
        Map<String, Object> device = this.dbMapper.getTaskDevById(devid);
        if (device == null) {
            throw new UEException("此任务已被其它用户删除！");
        }
        int status = ObjectUtil.getInt(device.get("status"), 1);
        if (status != 1) {
            SqlSession session = null;
            try {
                try {
                    session = MybatisUtil.sqlSessionFactory.openSession(true);
                    DBBugMapper dbBugMapper = (DBBugMapper) session.getMapper(DBBugMapper.class);
                    DbMapper dbMapper = (DbMapper) session.getMapper(DbMapper.class);
                    dbBugMapper.delDbResult2(devid);
                    Map<String, Object> dmap = new HashMap<>();
                    dmap.put("offset1", 0);
                    dmap.put("offset2", 0);
                    dmap.put("offset3", 0);
                    dmap.put("progress", 0);
                    dmap.put("devid", devid);
                    dbMapper.updateTaskDevice(dmap);
                    session.commit();
                    if (session != null) {
                        session.close();
                    }
                    String config = ObjectUtil.getString(device.get("confContent"), "{}");
                    Map<String, String> taskOption = (Map) JsonUtil.MAPPER.readValue(config, new TypeReference<Map<String, String>>() { // from class: com.datacloudsec.scan.service.impl.DbService.1
                    });
                    Task task = this.dbMapper.getTaskById(ObjectUtil.getInt(device.get("taskId")));
                    if (StringUtils.isNotBlank(task.getConfContent())) {
                        Map<String, String> taskConf = (Map) JsonUtil.MAPPER.readValue(task.getConfContent(), new TypeReference<Map<String, String>>() { // from class: com.datacloudsec.scan.service.impl.DbService.2
                        });
                        taskOption.putAll(taskConf);
                    }
                    try {
                        Map<String, Object> taskwebmap = new HashMap<>();
                        taskwebmap.put("devid", devid);
                        taskwebmap.put("status", 1);
                        taskwebmap.put("startTime", new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date()));
                        taskwebmap.put("scanCount", Integer.valueOf(ObjectUtil.getInt(device.get("scanCount"), 0) + 1));
                        this.dbMapper.updateTaskDevice(taskwebmap);
                        this.engine.dbScan(devid.intValue(), ObjectUtil.getString(device.get("ip"), ""), taskOption);
                        if (ObjectUtil.getInt(task.getAlarmType(), 0) == 1) {
                            device.put("taskType", task.getTaskType());
                            device.put("alarmType", task.getAlarmType());
                            device.put("alarmMethod", task.getAlarmMethod());
                            device.put("warningType", task.getWarningType());
                            device.put("mailAddr", task.getMailAddr());
                            device.put("smsAddr", task.getSmsAddr());
                            device.put("dest", task.getDest());
                            device.put("scanType", task.getType());
                            AlermJob.alermDevice(device);
                        }
                    } catch (Exception e) {
                        Object error = e instanceof UEException ? e.getMessage() : "连接引擎出错";
                        Map<String, Object> emap = new HashMap<>();
                        emap.put("error", error);
                        emap.put("status", 3);
                        emap.put("devid", devid);
                        this.dbMapper.updateTaskDevice(emap);
                        this.LOG.error("", e);
                    }
                } catch (Exception e2) {
                    session.rollback();
                    throw e2;
                }
            } catch (Throwable th) {
                if (session != null) {
                    session.close();
                }
                throw th;
            }
        }
    }

    public void startScanTask(Integer taskId) throws Exception {
        List<Map<String, Object>> taskDevList = this.dbMapper.getTaskDevByTid(taskId);
        if (taskDevList == null) {
            throw new UEException("此任务已被其它用户删除！");
        }
        for (Map<String, Object> dev : taskDevList) {
            if (1 != ObjectUtil.getInt(dev.get("status")).intValue()) {
                Integer devid = ObjectUtil.getInt(dev.get("id"));
                try {
                    start(devid);
                } catch (Exception e) {
                    this.LOG.error("手动扫描出错", e);
                }
            }
        }
    }

    @Transactional
    public void delDev(Integer devId) throws Exception {
        Map<String, Object> devMap = this.dbMapper.getTaskDevById(devId);
        if (1 == ObjectUtil.getInt(devMap.get("status")).intValue()) {
            throw new UEException("正在扫描，请先停止后再删除！");
        }
        this.dbBugMapper.delBbResult(devId);
        this.dbBugMapper.delBbVirus(devId);
        this.dbBugMapper.clearBbStatis(devId);
        this.dbMapper.delTaskDevById(devId);
    }

    public void addDev(HttpSession session, String devList, Integer taskId) throws Exception {
        Map<String, String> params = InitSystemTask.licenseApp.getLicenseLic().getParams();
        String cmp = ObjectUtil.getString(params.get("cmp"), "");
        LicCmp licCmp = getLicCp(cmp, "dbscan");
        int maxdevice = licCmp.getMaxdevice();
        List<Map<String, Object>> devListMap = (List) JsonUtil.MAPPER_ESCAPE_HTML.readValue(devList, ArrayList.class);
        int devIpCount = devListMap.size();
        if (maxdevice > 0 && this.dbMapper.getCountByType(ReportService.REPORT_STATE_FAILED) + devIpCount > maxdevice) {
            throw new UEException("当前资产数已达授权上限[" + maxdevice + "]");
        }
        List<Integer> devices = new ArrayList<>();
        for (Map<String, Object> devMap : devListMap) {
            String[] idarr = ObjectUtil.getString(devMap.get("id"), "").split("\\|");
            Map<String, Object> map = this.deviceMapper.getDevById(ObjectUtil.getInt(idarr[0]));
            if (map != null) {
                map.put("taskId", taskId);
                Map<String, Object> confContentMap = (Map) JsonUtil.MAPPER.readValue(ObjectUtil.getString(map.get("confContent"), ""), HashMap.class);
                List<Map<String, Object>> confListMap = (List) confContentMap.get(ReportService.REPORT_STATE_FAILED);
                String confStr = "";
                Iterator<Map<String, Object>> it = confListMap.iterator();
                while (true) {
                    if (!it.hasNext()) {
                        break;
                    }
                    Map<String, Object> conf = it.next();
                    if (idarr[2].equals(ObjectUtil.getString(conf.get("db"), ""))) {
                        confStr = JsonUtil.MAPPER.writeValueAsString(conf);
                        break;
                    }
                }
                map.put("confContent", confStr);
                map.put("type", 2);
                map.put("name", ObjectUtil.getString(devMap.get("name"), ""));
                this.dbMapper.insertTaskDevice(map);
                devices.add(ObjectUtil.getInt(map.get("id")));
            }
        }
        for (Integer devid : devices) {
            Map<String, Object> devMap2 = this.dbMapper.getTaskDevById(devid);
            Task task = this.dbMapper.getTaskById(taskId);
            if (task != null && task.getType().intValue() == 1) {
                User user = (User) session.getAttribute("userInfo");
                boolean bl = true;
                try {
                    start(ObjectUtil.getInt(devMap2.get("id")));
                } catch (Exception e) {
                    bl = false;
                    this.LOG.error("扫描出错", e);
                }
                if (bl) {
                    this.logMapper.insert(user == null ? "未登录" : user.getName(), "开始扫描数据库任务", "", 1, "扫描成功");
                } else {
                    this.logMapper.insert(user == null ? "未登录" : user.getName(), "开始扫描数据库任务", "", 2, "扫描失败");
                }
            }
        }
    }

    public List<Map<String, Object>> getDevDetailByTid(Integer id) throws Exception {
        return this.dbMapper.getDevDetailByTid(id);
    }

    public List<Map<String, Object>> bugPie(Integer id) throws Exception {
        return this.dbMapper.bugPie(id);
    }

    public List<Map<String, Object>> dbResult(Integer id, Integer offset, Integer limit) throws Exception {
        return this.dbMapper.dbResult(id, offset, limit);
    }

    public Integer dbResCount(Integer id) throws Exception {
        return this.dbMapper.dbResCount(id);
    }

    public Integer dbVirusCount(Integer id) throws Exception {
        return this.dbMapper.dbVirusCount(id);
    }

    public List<Map<String, Object>> dbVirus(Integer id, Integer offset, Integer limit) throws Exception {
        return this.dbMapper.dbVirus(id, offset, limit);
    }

    public List<Map<String, Object>> dbBugForDevice(Integer id) throws Exception {
        return this.dbMapper.dbBugForDevice(id);
    }

    public List<String> bugtimeForDevice(Integer id) throws Exception {
        return this.dbMapper.bugtimeForDevice(id);
    }

    public List<Map<String, Object>> dbBugTree(Integer id) throws Exception {
        return this.dbMapper.dbBugTree(id);
    }

    public List<Map<String, Object>> dbBugInter(Integer id) throws Exception {
        return this.dbMapper.dbBugInter(id);
    }

    public List<Map<String, Object>> newBug(Integer id) throws Exception {
        return this.dbMapper.newBug(id);
    }

    public List<Map<String, Object>> recovered(Integer id) throws Exception {
        return this.dbMapper.recovered(id);
    }

    private void delTask(HttpSession session, Integer id, Integer version) throws Exception {
        List<Map<String, Object>> devList = this.dbMapper.getTaskDevByTid(id);
        for (Map<String, Object> dev : devList) {
            Integer did = ObjectUtil.getInt(dev.get("id"));
            this.dbBugMapper.delDbResult2(did);
            this.dbBugMapper.delBbResult(did);
            this.dbBugMapper.delBbVirus(did);
            this.dbBugMapper.clearBbStatis(did);
        }
        stopTimer(session, id);
        this.dbMapper.delTaskDevByTid(id);
        Integer rcount = Integer.valueOf(this.dbMapper.delete(id, version, DataRule.getRuleWhere(session, "t_task")));
        if (rcount.intValue() == 0) {
            throw new UEException("数据已被修改或删除，请刷新页面或返回");
        }
    }

    public Map<String, Object> getPoliById(String poliid, Integer deviceid) throws Exception {
        return this.dbMapper.getPoliById(poliid, deviceid);
    }

    public int markBugErr(Integer id, Integer status) throws Exception {
        return this.dbMapper.markBugErr(id, status);
    }

    public File dbBackup(Task t) throws Exception {
        File dir = new File(Constant.TEMP_DIR, new StringBuilder(String.valueOf(System.nanoTime())).toString());
        if (!dir.exists()) {
            dir.mkdirs();
        }
        File f = new File(Constant.TEMP_DIR, new StringBuilder(String.valueOf(System.nanoTime())).toString());
        try {
            SerializeUtil.serializeObj(new File(dir, "task.backup"), t);
            List<Map<String, Object>> devList = this.dbMapper.getTaskDevByTid(t.getId());
            for (Map<String, Object> dev : devList) {
                Integer devid = ObjectUtil.getInt(dev.get("id"));
                File devDir = new File(dir, new StringBuilder().append(devid).toString());
                if (!devDir.exists()) {
                    devDir.mkdirs();
                }
                SerializeUtil.serializeObj(new File(devDir, "dev.backup"), dev);
                SerializeUtil.serializeObj(new File(devDir, "bug.backup"), this.dbMapper.getBugByDevId(devid));
                SerializeUtil.serializeObj(new File(devDir, "bug2.backup"), this.dbMapper.getBug2ByDevId(devid));
                SerializeUtil.serializeObj(new File(devDir, "sta.backup"), this.dbMapper.getStaByDevId(devid));
            }
            ComonZipUtil.zip(dir.getPath(), f.getPath());
            if (dir != null && dir.exists()) {
                FileUtils.deleteDirectory(dir);
            }
            return f;
        } catch (Exception e) {
            throw e;
        }
    }

    @Transactional
    public void dbRestore(HttpSession session, File f) throws Exception {
        File unzipFile = new File(Constant.COMMON_DIR, new StringBuilder(String.valueOf(System.nanoTime())).toString());
        ComonZipUtil.unzip(f, unzipFile);
        File taskFile = new File(unzipFile, "task.backup");
        Task t = (Task) SerializeUtil.deserializeObj(taskFile);
        Integer uid = ((User) session.getAttribute("userInfo")).getId();
        Integer count = this.dbMapper.getTaskCountByName(t.getName(), 4, uid, (Integer) null);
        if (count != null && count.intValue() > 0) {
            throw new UEException("dbTaskAlready:" + unzipFile.getName());
        }
        try {
            restore(unzipFile, t);
        } catch (Exception e) {
            FileUtils.deleteDirectory(unzipFile);
            throw e;
        }
    }

    private void restore(File unzipFile, Task t) throws Exception {
        Map<String, Object> device;
        if (unzipFile == null || t == null) {
            return;
        }
        this.dbMapper.insert(t);
        for (File taskDir : unzipFile.listFiles()) {
            if (!taskDir.getName().equals("task.backup") && (device = (Map) SerializeUtil.deserializeObj(new File(taskDir, "dev.backup"))) != null && device.size() != 0) {
                device.put("taskId", t.getId());
                this.dbMapper.inserTaskDevById(device);
                Integer devId = ObjectUtil.getInt(device.get("id"));
                List<Map<String, Object>> bugs = (List) SerializeUtil.deserializeObj(new File(taskDir, "bug.backup"));
                if (bugs != null && bugs.size() > 0) {
                    this.dbMapper.insertDbRes(devId, bugs);
                }
                List<Map<String, Object>> bugs2 = (List) SerializeUtil.deserializeObj(new File(taskDir, "bug2.backup"));
                if (bugs2 != null && bugs2.size() > 0) {
                    this.dbMapper.insertDbRes2(devId, bugs2);
                }
                List<Map<String, Object>> stas = (List) SerializeUtil.deserializeObj(new File(taskDir, "sta.backup"));
                if (stas != null && stas.size() > 0) {
                    this.dbMapper.inserDbSta(devId, stas);
                }
            }
        }
        startTimer(t.getId(), t.getType(), t.getPeriodTime(), t.getAlarmType(), t.getAlarmMethod(), t.getAlarmTime());
        FileUtils.deleteDirectory(unzipFile);
    }

    @Transactional
    public void dbEnter(HttpSession session, String filename) throws Exception {
        File f = new File(Constant.COMMON_DIR, filename);
        if (f == null || !f.exists()) {
            this.LOG.error("数据库恢复，文件不存在！");
            return;
        }
        User u = (User) session.getAttribute("userInfo");
        Task t = (Task) SerializeUtil.deserializeObj(new File(f, "task.backup"));
        t.setName(String.valueOf(t.getName()) + System.nanoTime());
        t.setUid(u.getId());
        try {
            restore(f, t);
        } catch (Exception e) {
            FileUtils.deleteDirectory(f);
            throw e;
        }
    }

    public void impDbResult(File f, Integer taskId) throws Exception {
        if (f == null || f.length() == 0) {
            throw new UEException("文件错误");
        }
        try {
            Map<String, Object> result = (Map) JsonUtil.MAPPER.readValue(f, new TypeReference<Map<String, Object>>() { // from class: com.datacloudsec.scan.service.impl.DbService.3
            });
            if (MapUtils.isEmpty(result)) {
                throw new UEException("结果不能为空");
            }
            String ip = ObjectUtil.getString(result.get("ip"), "");
            if (StringUtils.isEmpty(ip)) {
                throw new UEException("未发现IP地址");
            }
            String dbtype = ObjectUtil.getString(result.get("dbtype"), "");
            int port = ObjectUtil.getInt(result.get("ip"), 0);
            String error = ObjectUtil.getString(result.get("error"), "");
            String startTime = ObjectUtil.getString(result.get("startTime"), "");
            String endTime = ObjectUtil.getString(result.get("endTime"), "");
            boolean bl = false;
            Iterator it = this.dbMapper.getDevByTidAndIps(taskId, ip).iterator();
            while (true) {
                if (!it.hasNext()) {
                    break;
                }
                Map<String, Object> dev = (Map) it.next();
                String devip = ObjectUtil.getString(dev.get("ip"), "");
                if (ip.equals(devip)) {
                    String confStr = ObjectUtil.getString(dev.get("confContent"), "");
                    if (StringUtils.isBlank(confStr)) {
                        continue;
                    } else {
                        Map<String, Object> confMap = (Map) JsonUtil.MAPPER.readValue(confStr, new TypeReference<Map<String, Object>>() { // from class: com.datacloudsec.scan.service.impl.DbService.4
                        });
                        if (MapUtils.isEmpty(confMap)) {
                            continue;
                        } else {
                            String confDbtype = ObjectUtil.getString(confMap.get("db"), "");
                            int confPort = ObjectUtil.getInt(result.get("ip"), 0);
                            if (dbtype.equals(confDbtype) && port == confPort) {
                                Integer devid = ObjectUtil.getInt(dev.get("id"));
                                bl = true;
                                if (StringUtils.isNotBlank(error)) {
                                    this.dbMapper.updDbDev(devid, startTime, endTime, 3, error);
                                } else {
                                    this.dbMapper.updDbDev(devid, startTime, endTime, 2, (String) null);
                                    List<Map<String, Object>> resultList = (List) result.get("result");
                                    if (CollectionUtils.isNotEmpty(resultList)) {
                                        for (Map<String, Object> res : resultList) {
                                            String detail = ObjectUtil.getString(res.get("detail"), "");
                                            if (!StringUtils.isBlank(detail)) {
                                                List<Map<String, Object>> info = (List) JsonUtil.MAPPER.readValue(detail, new TypeReference<List<Map<String, Object>>>() { // from class: com.datacloudsec.scan.service.impl.DbService.5
                                                });
                                                if (CollectionUtils.isNotEmpty(info)) {
                                                    if (info.size() == 1) {
                                                        Map<String, Object> m = info.get(0);
                                                        if (m.size() == 2 && m.containsKey("variable_name") && m.containsKey("variable_value")) {
                                                            Map<String, Object> newMap = new HashMap<>();
                                                            newMap.put((String) m.get("variable_name"), m.get("variable_value"));
                                                            info.clear();
                                                            info.add(newMap);
                                                        }
                                                    }
                                                    res.put("detail", JsonUtil.MAPPER.writeValueAsString(info));
                                                }
                                            }
                                        }
                                        if (ObjectUtil.getInt(dev.get("scanCount"), 0) != 1) {
                                            this.dbMapper.dbAddResults2(devid, resultList);
                                        } else {
                                            this.dbMapper.dbAddResults(devid, resultList);
                                        }
                                    }
                                    if (ObjectUtil.getInt(dev.get("scanCount"), 0) != 1) {
                                        List<Map<String, Object>> oldBugs = this.dbBugMapper.getDbResult(devid);
                                        this.dbBugMapper.delBbResult(devid);
                                        this.dbBugMapper.dbCopyResult(devid);
                                        this.dbBugMapper.delDbResult2(devid);
                                        if (oldBugs != null && oldBugs.size() > 0) {
                                            this.dbBugMapper.addDbResult2(oldBugs, devid);
                                        }
                                    }
                                    Map<String, Object> db = this.dbBugMapper.bugCountByDev(devid);
                                    this.dbBugMapper.addDbStatis(1, Integer.valueOf(ObjectUtil.getInt(db.get("jj"), 0)), devid);
                                    this.dbBugMapper.addDbStatis(2, Integer.valueOf(ObjectUtil.getInt(db.get("gw"), 0)), devid);
                                    this.dbBugMapper.addDbStatis(3, Integer.valueOf(ObjectUtil.getInt(db.get("zw"), 0)), devid);
                                    this.dbBugMapper.addDbStatis(4, Integer.valueOf(ObjectUtil.getInt(db.get("dw"), 0)), devid);
                                    this.dbBugMapper.addDbStatis(5, Integer.valueOf(ObjectUtil.getInt(db.get("xx"), 0)), devid);
                                    List<Map<String, Object>> queryDbBug = this.alarmlogMapper.queryDbBug(devid);
                                    if (CollectionUtils.isNotEmpty(queryDbBug)) {
                                        this.alarmlogMapper.delAlarmlogByTime();
                                        this.alarmlogMapper.batchInsert(queryDbBug);
                                    }
                                    Task task = this.dbMapper.getTaskById(taskId);
                                    FtpUtil.reportUpload(task, dev, (String) IReport.REPORT_CHK.get("db"), "db");
                                    SysLogJob.addBugs(this.dbBugMapper.getBugsForLog(devid));
                                    if (ObjectUtil.getInt(dev.get("alarmType"), 0) == 1) {
                                        AlermJob.alermDevice(dev);
                                    }
                                }
                            }
                        }
                    }
                }
            }
            if (!bl) {
                throw new UEException("资产IP或资产类型不匹配");
            }
        } catch (Exception e) {
            throw new UEException("文件内容错误", e);
        }
    }
}
